Crate skribble_color

Crate skribble_color 

Re-exports

pub use palette;

Structs

LabHue
A hue type for the CIE L*a*b* family of color spaces.
OklabHue
A hue type for the Oklab color space.
RgbHue
A hue type for the RGB family of color spaces.

Enums

Color
This enum represents a color in any of the supported css color formats.
ColorError

Traits

FromColor
A trait for converting one color from another, in a possibly lossy way.

Type Aliases

Hsla
Linear HSL with an alpha component. See the Hsla implementation in Alpha.
Hwba
Linear HWB with an alpha component. See the Hwba implementation in Alpha.
Laba
CIE L*a*b* (CIELAB) with an alpha component. See the Laba implementation in Alpha.
Lcha
CIE L*C*h° with an alpha component. See the Lcha implementation in Alpha.
Oklaba
Oklab with an alpha component. See the Oklaba implementation in Alpha.
Oklcha
Oklch with an alpha component. See the Oklcha implementation in Alpha.
Rgba
Generic RGB with an alpha component. See the Rgba implementation in Alpha.