Re-exports
pub use palette;
Structs
- LabHue
- A hue type for the CIE L*a*b* family of color spaces.
- Oklab
Hue - A hue type for the Oklab color space.
- RgbHue
- A hue type for the RGB family of color spaces.
Enums
- Color
- This enum represents a color in any of the supported css color formats.
- Color
Error
Traits
- From
Color - A trait for converting one color from another, in a possibly lossy way.
Type Aliases
- Hsla
- Linear HSL with an alpha component. See the
Hslaimplementation inAlpha. - Hwba
- Linear HWB with an alpha component. See the
Hwbaimplementation inAlpha. - Laba
- CIE L*a*b* (CIELAB) with an alpha component. See the
Labaimplementation inAlpha. - Lcha
- CIE L*C*h° with an alpha component. See the
Lchaimplementation inAlpha. - Oklaba
- Oklab with an alpha component. See the
Oklabaimplementation inAlpha. - Oklcha
- Oklch with an alpha component. See the
Oklchaimplementation inAlpha. - Rgba
- Generic RGB with an alpha component. See the
Rgbaimplementation inAlpha.